# Stoichiometric <img src=https://github.com/jherfson/Stoichiometric-1/blob/main/ico/icons8-test-tube-40.png>

<img src="https://img.shields.io/static/v1?label=pymatgen&message=framework&color=blue&style=for-the-badge&logo=PYMATGEN"/>

## Descrição do Projeto

Este trabalho tem como objetivo realizar cálculo de balanceamento de reações químicas e Cálculo estequiométrico usando a biblitoca [Pymatgen](https://pymatgen.org/).

## Requisitos

* [Pymatgen](https://pymatgen.org/)
* [Anaconda](https://www.anaconda.com/products/individual)
## Instalação

* Download do pacote Stoichiometric.zip
* Na pasta raiz do projeto, usar o comando para realizar a instalação da biblioteca:

```
pip install e
```

## Usando o programa

Acessando o direitório 

```
example/sample.py
```
A entrada vai da equação:

```
Cl2 + 2NaOH -> NaCl + NaClO + H2O 
```
Dando entrada também da massa do produto em grama:

```
5.0
```

## Usando no Windows
É necessário que tenha instalado o [anaconda](https://www.anaconda.com/products/individual) no computador:
Click com o botão direito mouse no arquivo stoichiometric.bat, Run as adminstrator.
```
stoichiometric.bat
```
